/* 
 * Copyright 2015 Key Bridge LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package us.gov.dod.standard.ssrf._3_1.metadata.lists;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;
import us.gov.dod.standard.ssrf._3_1.*;

/**
 * Enumerated values for fields using the ListCCY type.
 * <p>
 * Used in
 * {@link Administrative}, {@link Allotment}, {@link Antenna}, {@link Assignment}, {@link ChannelPlan}, {@link Common}, {@link Contact}, {@link ExternalReference}, {@link FEDeployment}, {@link ForceElement}, {@link IntfReport}, {@link JRFL}, {@link Loadset}, {@link Location}, {@link Message}, {@link Note}, {@link Organisation}, {@link RFSystem}, {@link RadiationPlan}, {@link Receiver}, {@link Role}, {@link SSReply}, {@link SSRequest}, {@link Satellite}, {@link TOA}, {@link Transmitter}
 * <p>
 * @author Key Bridge LLC <developer@keybridge.ch>
 * @version 3.1.0, 04/02/2015
 */
@XmlType(name = "ListCCY")
@XmlEnum
public enum ListCCY {

  /**
   * Afghanistan
   */
  AFG("AFG"),
  /**
   * Albania
   */
  ALB("ALB"),
  /**
   * Algeria
   */
  DZA("DZA"),
  /**
   * Andorra
   */
  AND("AND"),
  /**
   * Angola
   */
  AGO("AGO"),
  /**
   * Antigua and Barbuda
   */
  ATG("ATG"),
  /**
   * Argentine Republic
   */
  ARG("ARG"),
  /**
   * Armenia
   */
  ARM("ARM"),
  /**
   * Australia
   */
  AUS("AUS"),
  /**
   * Austria
   */
  AUT("AUT"),
  /**
   * Azerbaijan
   */
  AZE("AZE"),
  /**
   * Bahamas
   */
  BHS("BHS"),
  /**
   * Bahrain
   */
  BHR("BHR"),
  /**
   * Bangladesh
   */
  BGD("BGD"),
  /**
   * Barbados
   */
  BRB("BRB"),
  /**
   * Belarus
   */
  BLR("BLR"),
  /**
   * Belgium
   */
  BEL("BEL"),
  /**
   * Belize
   */
  BLZ("BLZ"),
  /**
   * Benin
   */
  BEN("BEN"),
  /**
   * Bhutan
   */
  BTN("BTN"),
  /**
   * Bolivia
   */
  BOL("BOL"),
  /**
   * Bosnia and Herzegovina
   */
  BIH("BIH"),
  /**
   * Botswana
   */
  BWA("BWA"),
  /**
   * Brazil
   */
  BRA("BRA"),
  /**
   * Brunei Darussalam
   */
  BRN("BRN"),
  /**
   * Bulgaria
   */
  BGR("BGR"),
  /**
   * Burkina Faso
   */
  BFA("BFA"),
  /**
   * Burundi
   */
  BDI("BDI"),
  /**
   * Cambodia
   */
  KHM("KHM"),
  /**
   * Cameroon
   */
  CMR("CMR"),
  /**
   * Canada
   */
  CAN("CAN"),
  /**
   * Cape Verde
   */
  CPV("CPV"),
  /**
   * CCEB Nations (AUS, CAN, GBR, NZL, USA)
   */
  CCEB("CCEB"),
  /**
   * Central African Republic
   */
  CAF("CAF"),
  /**
   * Chad
   */
  TCD("TCD"),
  /**
   * Chemical Weapons Convention States
   */
  CWCS("CWCS"),
  /**
   * Chile
   */
  CHL("CHL"),
  /**
   * China
   */
  CHN("CHN"),
  /**
   * Colombia
   */
  COL("COL"),
  /**
   * Comoros
   */
  COM("COM"),
  /**
   * Congo
   */
  COG("COG"),
  /**
   * Congo (Democratic Republic of the)
   */
  COD("COD"),
  /**
   * Costa Rica
   */
  CRI("CRI"),
  /**
   * Ivory Coast
   */
  CIV("CIV"),
  /**
   * Croatia
   */
  HRV("HRV"),
  /**
   * Cuba
   */
  CUB("CUB"),
  /**
   * Cyprus (See footnote 1)
   */
  CYP("CYP"),
  /**
   * Czech Republic
   */
  CZE("CZE"),
  /**
   * Denmark
   */
  DNK("DNK"),
  /**
   * Djibouti
   */
  DJI("DJI"),
  /**
   * Dominica
   */
  DMA("DMA"),
  /**
   * Dominican Republic
   */
  DOM("DOM"),
  /**
   * East Timor
   */
  TLS("TLS"),
  /**
   * Ecuador
   */
  ECU("ECU"),
  /**
   * Egypt
   */
  EGY("EGY"),
  /**
   * El Salvador
   */
  SLV("SLV"),
  /**
   * Equatorial Guinea
   */
  GNQ("GNQ"),
  /**
   * Eritrea
   */
  ERI("ERI"),
  /**
   * Estonia
   */
  EST("EST"),
  /**
   * Ethiopia
   */
  ETH("ETH"),
  /**
   * Fiji
   */
  FJI("FJI"),
  /**
   * Finland
   */
  FIN("FIN"),
  /**
   * FIVE EYES (USA, CAN, GBR, AUS, NZL)
   */
  FVEY("FVEY"),
  /**
   * FOUR EYES (USA, CAN, GBR, AUS)
   */
  ACGU("ACGU"),
  /**
   * France
   */
  FRA("FRA"),
  /**
   * Gabon
   */
  GAB("GAB"),
  /**
   * Gambia
   */
  GMB("GMB"),
  /**
   * Georgia
   */
  GEO("GEO"),
  /**
   * Germany
   */
  DEU("DEU"),
  /**
   * Ghana
   */
  GHA("GHA"),
  /**
   * Greece
   */
  GRC("GRC"),
  /**
   * Grenada
   */
  GRD("GRD"),
  /**
   * Guatemala
   */
  GTM("GTM"),
  /**
   * Guinea
   */
  GIN("GIN"),
  /**
   * Guinea-Bissau
   */
  GNB("GNB"),
  /**
   * Guyana
   */
  GUY("GUY"),
  /**
   * Haiti
   */
  HTI("HTI"),
  /**
   * Honduras
   */
  HND("HND"),
  /**
   * Hungary
   */
  HUN("HUN"),
  /**
   * Iceland
   */
  ISL("ISL"),
  /**
   * India
   */
  IND("IND"),
  /**
   * Indonesia
   */
  IDN("IDN"),
  /**
   * Iran
   */
  IRN("IRN"),
  /**
   * Iraq
   */
  IRQ("IRQ"),
  /**
   * Ireland
   */
  IRL("IRL"),
  /**
   * Israel
   */
  ISR("ISR"),
  /**
   * Italy
   */
  ITA("ITA"),
  /**
   * Jamaica
   */
  JAM("JAM"),
  /**
   * Japan
   */
  JPN("JPN"),
  /**
   * Jordan
   */
  JOR("JOR"),
  /**
   * Kazakhstan
   */
  KAZ("KAZ"),
  /**
   * Kenya
   */
  KEN("KEN"),
  /**
   * Kiribati
   */
  KIR("KIR"),
  /**
   * Korea, North
   */
  PRK("PRK"),
  /**
   * Korea, South
   */
  KOR("KOR"),
  /**
   * Kosovo
   */
  @XmlEnumValue("YU-KM")
  YU_KM("YU-KM"),
  /**
   * Kuwait
   */
  KWT("KWT"),
  /**
   * Kyrgyzstan
   */
  KGZ("KGZ"),
  /**
   * Laos
   */
  LAO("LAO"),
  /**
   * Latvia
   */
  LVA("LVA"),
  /**
   * Lebanon
   */
  LBN("LBN"),
  /**
   * Lesotho
   */
  LSO("LSO"),
  /**
   * Liberia
   */
  LBR("LBR"),
  /**
   * Libya
   */
  LBY("LBY"),
  /**
   * Liechtenstein
   */
  LIE("LIE"),
  /**
   * Lithuania
   */
  LTU("LTU"),
  /**
   * Luxembourg
   */
  LUX("LUX"),
  /**
   * Madagascar
   */
  MDG("MDG"),
  /**
   * Malawi
   */
  MWI("MWI"),
  /**
   * Malaysia
   */
  MYS("MYS"),
  /**
   * Maldives
   */
  MDV("MDV"),
  /**
   * Mali
   */
  MLI("MLI"),
  /**
   * Malta
   */
  MLT("MLT"),
  /**
   * Marshall Islands
   */
  MHL("MHL"),
  /**
   * Mauritania
   */
  MRT("MRT"),
  /**
   * Mauritius
   */
  MUS("MUS"),
  /**
   * Mexico
   */
  MEX("MEX"),
  /**
   * Micronesia
   */
  FSM("FSM"),
  /**
   * Moldova
   */
  MDA("MDA"),
  /**
   * Monaco
   */
  MCO("MCO"),
  /**
   * Mongolia
   */
  MNG("MNG"),
  /**
   * Montenegro
   */
  MNE("MNE"),
  /**
   * Morocco
   */
  MAR("MAR"),
  /**
   * Mozambique
   */
  MOZ("MOZ"),
  /**
   * Myanmar
   */
  MMR("MMR"),
  /**
   * Namibia
   */
  NAM("NAM"),
  /**
   * Nauru
   */
  NRU("NRU"),
  /**
   * Nepal
   */
  NPL("NPL"),
  /**
   * Netherlands
   */
  NLD("NLD"),
  /**
   * New Zealand
   */
  NZL("NZL"),
  /**
   * Nicaragua
   */
  NIC("NIC"),
  /**
   * Niger
   */
  NER("NER"),
  /**
   * Nigeria
   */
  NGA("NGA"),
  /**
   * NATO Nations (28 Nations: ALB, BEL, BUL, CAN, CZE, D, DNK, E, EST, F, G,
   * GRC, HNG, HOL, HRV, I, ISL, LUX, LIT, LVA, NOR, POL, POR, ROU, SVK, SVN,
   * TUR, USA)
   */
  NATO("NATO"),
  /**
   * Norway
   */
  NOR("NOR"),
  /**
   * Oman
   */
  OMN("OMN"),
  /**
   * Pakistan
   */
  PAK("PAK"),
  /**
   * Palau
   */
  PLW("PLW"),
  /**
   * Palestine
   */
  PSE("PSE"),
  /**
   * Panama
   */
  PAN("PAN"),
  /**
   * Papua New Guinea
   */
  PNG("PNG"),
  /**
   * Paraguay
   */
  PRY("PRY"),
  /**
   * Peru
   */
  PER("PER"),
  /**
   * Philippines
   */
  PHL("PHL"),
  /**
   * Poland
   */
  POL("POL"),
  /**
   * Portugal
   */
  PRT("PRT"),
  /**
   * Qatar
   */
  QAT("QAT"),
  /**
   * Romania
   */
  ROU("ROU"),
  /**
   * Russian Federation
   */
  RUS("RUS"),
  /**
   * Rwanda
   */
  RWA("RWA"),
  /**
   * Saint Kitts and Nevis
   */
  KNA("KNA"),
  /**
   * Saint Lucia
   */
  LCA("LCA"),
  /**
   * Saint Vincent and the Grenadines
   */
  VCT("VCT"),
  /**
   * Samoa
   */
  WSM("WSM"),
  /**
   * San Marino
   */
  SMR("SMR"),
  /**
   * Sao Tome and Principe
   */
  STP("STP"),
  /**
   * Saudi Arabia
   */
  SAU("SAU"),
  /**
   * Senegal
   */
  SEN("SEN"),
  /**
   * Serbia
   */
  SRB("SRB"),
  /**
   * Seychelles
   */
  SYC("SYC"),
  /**
   * Sierra Leone
   */
  SLE("SLE"),
  /**
   * Singapore
   */
  SGP("SGP"),
  /**
   * Slovakia
   */
  SVK("SVK"),
  /**
   * Slovenia
   */
  SVN("SVN"),
  /**
   * Solomon Islands
   */
  SLB("SLB"),
  /**
   * Somalia
   */
  SOM("SOM"),
  /**
   * South Africa
   */
  ZAF("ZAF"),
  /**
   * Spain
   */
  ESP("ESP"),
  /**
   * Sri Lanka
   */
  LKA("LKA"),
  /**
   * Sudan
   */
  SDN("SDN"),
  /**
   * Suriname
   */
  SUR("SUR"),
  /**
   * Swaziland
   */
  SWZ("SWZ"),
  /**
   * Sweden
   */
  SWE("SWE"),
  /**
   * Switzerland
   */
  CHE("CHE"),
  /**
   * Syria
   */
  SYR("SYR"),
  /**
   * Taiwan
   */
  TWN("TWN"),
  /**
   * Tajikistan
   */
  TJK("TJK"),
  /**
   * Tanzania
   */
  TZA("TZA"),
  /**
   * Thailand
   */
  THA("THA"),
  /**
   * The former Yugoslav Republic of Macedonia (See footnote 2)
   */
  FYR("FYR"),
  /**
   * THREE EYES (USA, CAN, GBR)
   */
  TEYE("TEYE"),
  /**
   * Togo
   */
  TGO("TGO"),
  /**
   * Tonga
   */
  TON("TON"),
  /**
   * Trinidad and Tobago
   */
  TTO("TTO"),
  /**
   * Tunisia
   */
  TUN("TUN"),
  /**
   * Turkey
   */
  TUR("TUR"),
  /**
   * Turkmenistan
   */
  TKM("TKM"),
  /**
   * Tuvalu
   */
  TUV("TUV"),
  /**
   * Uganda
   */
  UGA("UGA"),
  /**
   * Ukraine
   */
  UKR("UKR"),
  /**
   * United Arab Emirates
   */
  ARE("ARE"),
  /**
   * United Kingdom
   */
  GBR("GBR"),
  /**
   * United Nations
   */
  UN("UN"),
  /**
   * United States (CONUS)
   */
  USC("USC"),
  /**
   * United States and Possessions
   */
  USP("USP"),
  /**
   * United States of America
   */
  USA("USA"),
  /**
   * Unknown
   */
  UNKN("UNKN"),
  /**
   * Uruguay
   */
  URY("URY"),
  /**
   * Uzbekistan
   */
  UZB("UZB"),
  /**
   * Vanuatu
   */
  VUT("VUT"),
  /**
   * Vatican City State
   */
  VAT("VAT"),
  /**
   * Venezuela
   */
  VEN("VEN"),
  /**
   * Vietnam
   */
  VNM("VNM"),
  /**
   * Yemen
   */
  YEM("YEM"),
  /**
   * Yugoslavia (YUG) - Deprecated
   */
  @XmlEnumValue("YO05")
  YO_05("YO05"),
  /**
   * Zambia
   */
  ZMB("ZMB"),
  /**
   * Zimbabwe
   */
  ZWE("ZWE");

  private final String value;

  ListCCY(String v) {
    value = v;
  }

  public String value() {
    return value;
  }

  public static ListCCY fromValue(String v) {
    for (ListCCY c : ListCCY.values()) {
      if (c.value.equals(v)) {
        return c;
      }
    }
    throw new IllegalArgumentException(v);
  }

}
